==> cppad_2015.00.00.2.orig.tar.gz: cppad-20150000.2/doc/_checkpoint_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'ad.xml',
'advalued.xml',
'atomic.xml',
'checkpoint.xml'
];
var list_down3 = [
'ad_ctor.xml',
'ad_assign.xml',
'convert.xml',
'advalued.xml',
'boolvalued.xml',
'vecad.xml',
'base_require.xml'
];
var list_down2 = [
'arithmetic.xml',
'std_math_ad.xml',
'mathother.xml',
'condexp.xml',
'discrete.xml',
'atomic.xml'
];
var list_down1 = [
'checkpoint.xml',
'atomic_base.xml'
];
var list_down0 = [
'checkpoint.cpp.xml'
];
var list_current0 = [
'checkpoint.xml#Syntax',
'checkpoint.xml#Purpose',
'checkpoint.xml#Method',
'checkpoint.xml#constructor',
'checkpoint.xml#Base',
'checkpoint.xml#ADVector',
'checkpoint.xml#name',
'checkpoint.xml#ax',
'checkpoint.xml#ay',
'checkpoint.xml#option',
'checkpoint.xml#algo',
'checkpoint.xml#afun',
'checkpoint.xml#clear',
'checkpoint.xml#clear.Restriction',
'checkpoint.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2016.00.00.1.orig.tar.gz: cppad-20160000.1/doc/_checkpoint_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'ad.xml',
'advalued.xml',
'atomic.xml',
'checkpoint.xml'
];
var list_down3 = [
'ad_ctor.xml',
'ad_assign.xml',
'convert.xml',
'advalued.xml',
'boolvalued.xml',
'vecad.xml',
'base_require.xml'
];
var list_down2 = [
'arithmetic.xml',
'unary_standard_math.xml',
'binary_math.xml',
'condexp.xml',
'discrete.xml',
'numeric_limits.xml',
'atomic.xml'
];
var list_down1 = [
'checkpoint.xml',
'atomic_base.xml'
];
var list_down0 = [
'checkpoint.cpp.xml'
];
var list_current0 = [
'checkpoint.xml#Syntax',
'checkpoint.xml#Purpose',
'checkpoint.xml#Purpose.Reduce Memory',
'checkpoint.xml#Purpose.Faster Recording',
'checkpoint.xml#Method',
'checkpoint.xml#constructor',
'checkpoint.xml#Base',
'checkpoint.xml#ADVector',
'checkpoint.xml#name',
'checkpoint.xml#ax',
'checkpoint.xml#ay',
'checkpoint.xml#sparsity',
'checkpoint.xml#size_var',
'checkpoint.xml#option',
'checkpoint.xml#algo',
'checkpoint.xml#atom_fun',
'checkpoint.xml#clear',
'checkpoint.xml#clear.Restriction',
'checkpoint.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
